<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_TopLevelCategory
 * @copyright   Copyright (c) 2017 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Douglas Radburn <douglas.radburn@pinpointdesigns.co.uk>
 */

namespace Pinpoint\TopLevelCategory\Setup;

use \Magento\Framework\Setup\InstallDataInterface;
use \Magento\Framework\Setup\ModuleContextInterface;
use \Magento\Framework\Setup\ModuleDataSetupInterface;
use \Magento\Cms\Model\BlockFactory;
use \Magento\Cms\Model\BlockRepository;
use \Magento\Eav\Setup\EavSetupFactory;

/** InstallDataInterface */
class InstallData implements InstallDataInterface
{

    /**
     * @var BlockFactory
     */
    protected $_blockFactory;
    /**
     * @var BlockRepository
     */
    protected $_blockRepository;
    /**
     * @var EAVSetupFactory
     */
    protected $_eavSetupFactory;

    /**
     * @param BlockFactory $blockFactory
     * @param BlockRepository $blockRepository
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(
        BlockFactory $blockFactory,
        BlockRepository $blockRepository,
        EavSetupFactory $eavSetupFactory
    )
    {
        $this->_blockFactory = $blockFactory;
        $this->_blockRepository = $blockRepository;
        $this->_eavSetupFactory = $eavSetupFactory;
    }

    /**
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        // add CMS Static Blocks for USP
        $data = [
            'title' => 'Top Level Category',
            'identifier' => 'top-level-category',
            'stores' => ['0'],
            'is_active' => 1,
            'content' => '{{block class="Pinpoint\\\\TopLevelCategory\\\\Block\\\\TopLevelCategory" block_id="top_level_category"}}'
        ];

        $newBlock = $this->_blockFactory->create(['data' => $data]);
        $this->_blockRepository->save($newBlock);

        $setup->endSetup();

    }
}
